@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Iller::MintFiles;
 
-our $VERSION = '0.1001'; # VERSION
+our $VERSION = '0.1100'; # VERSION
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -24,6 +24,32 @@ override 'merged_section_data' => sub {
 };
 
 1;
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Dist::Zilla::Plugin::Iller::MintFiles
+
+=head1 VERSION
+
+version 0.1002
+
+=head1 AUTHOR
+
+Erik Carlsson <info@code301.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Erik Carlsson.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
 __DATA__
 ___[ Changes ]___
 Revision history for {{ $dist->name }}
